==> apache-storm-2.3.0-src.zip: apache-storm-2.3.0/external/storm-rocketmq/src/test/java/org/apache/storm/rocketmq/common/mapper/FieldNameBasedTupleToMessageMapperTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.rocketmq.common.mapper;

import org.apache.storm.rocketmq.TestUtils;
import org.apache.storm.tuple.Tuple;
import org.junit.Test;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertEquals;

public class FieldNameBasedTupleToMessageMapperTest {
    @Test
    public void withMessageBodySerializer() throws Exception {
        FieldNameBasedTupleToMessageMapper messageMapper = new FieldNameBasedTupleToMessageMapper("f1", "f2");
        Tuple tuple = TestUtils.generateTestTuple("f1", "f2", "v1", "v2");
        assertEquals("v1", messageMapper.getKeyFromTuple(tuple));
        assertArrayEquals("v2".getBytes(), messageMapper.getValueFromTuple(tuple));
    }
}

==> apache-storm-2.5.0-src.zip: apache-storm-2.5.0/external/storm-rocketmq/src/test/java/org/apache/storm/rocketmq/common/mapper/FieldNameBasedTupleToMessageMapperTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.rocketmq.common.mapper;

import org.apache.storm.rocketmq.TestUtils;
import org.apache.storm.tuple.Tuple;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertArrayEquals;
import static org.junit.jupiter.api.Assertions.assertEquals;

public class FieldNameBasedTupleToMessageMapperTest {
    @Test
    public void withMessageBodySerializer() throws Exception {
        FieldNameBasedTupleToMessageMapper messageMapper = new FieldNameBasedTupleToMessageMapper("f1", "f2");
        Tuple tuple = TestUtils.generateTestTuple("f1", "f2", "v1", "v2");
        assertEquals("v1", messageMapper.getKeyFromTuple(tuple));
        assertArrayEquals("v2".getBytes(), messageMapper.getValueFromTuple(tuple));
    }
}
